# Generated by Django 2.2.14 on 2021-05-29 09:05

import django.contrib.postgres.fields.jsonb
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('carousels', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='carousel',
            name='settings',
            field=django.contrib.postgres.fields.jsonb.JSONField(blank=True, default=dict, help_text="For example: \n        {\n            items: 1,\n            loop: true,\n            dots: false,\n            nav: true,\n            responsiveClass: true,\n            animateOut: 'fadeOut',\n            autoplay: true,\n            autoplayHoverPause: true,\n            autoplayTimeout: 5000,\n            smartSpeed: 1000,\n            fluidSpeed: 1000,\n            autoplaySpeed: 1000,\n            slideTransition: 'linear',\n            center: true,\n            responsive: {\n                0: {\n                    items: 1,\n                },\n                576: {\n                    items: 2,\n                },\n                768: {\n                    items: 2.5,\n                },\n                992: {\n                    items: 3,\n                },\n                1200: {\n                    items: 4.75,\n                }\n            }\n        }\n    ", verbose_name='settings'),
        ),
    ]
