# Generated by Django 2.2.14 on 2021-05-23 12:47

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Carousel',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('slug', models.SlugField(help_text='slug', max_length=20, unique=True, verbose_name='identifier')),
            ],
            options={
                'verbose_name': 'carousel',
                'verbose_name_plural': 'carousels',
            },
        ),
        migrations.CreateModel(
            name='Slide',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('position', models.PositiveSmallIntegerField(default=0, verbose_name='position')),
                ('title', models.CharField(blank=True, max_length=100, verbose_name='title')),
                ('text', models.TextField(blank=True, verbose_name='text')),
                ('button', models.CharField(blank=True, help_text='label', max_length=30, verbose_name='button')),
                ('url', models.CharField(blank=True, help_text='CTA', max_length=100, verbose_name='URL')),
                ('background', models.ImageField(blank=True, default=None, null=True, upload_to='slides', verbose_name='background')),
                ('carousel', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='carousels.Carousel', verbose_name='carousel')),
            ],
            options={
                'verbose_name': 'slide',
                'verbose_name_plural': 'slides',
                'ordering': ('position',),
            },
        ),
    ]
